@@ -1766,7 +1766,7 @@ found:
 	;
     }
 
-    surface = malloc (sizeof (cairo_xlib_surface_t));
+    surface = _cairo_malloc (sizeof (cairo_xlib_surface_t));
     if (unlikely (surface == NULL))
 	return _cairo_surface_create_in_error (_cairo_error (CAIRO_STATUS_NO_MEMORY));
 
@@ -1886,7 +1886,7 @@ static cairo_bool_t valid_size (int width, int height)
     /* Note: the minimum surface size allowed in the X protocol is 1x1.
      * However, as we historically did not check the minimum size we
      * allowed applications to lie and set the correct size later (one hopes).
-     * To preserve compatability we must allow applications to use
+     * To preserve compatibility we must allow applications to use
      * 0x0 surfaces.
      */
     return (width  >= 0 && width  <= XLIB_COORD_MAX &&
